@@ -52,14 +52,16 @@ class AnyBlokCore(Blok):
     author = 'Suzanne Jean-Sébastien'
     logo = '../anyblok-logo_alpha_256.png'
 
-    def pre_migration(self, latest_version):
+    def pre_migration(self, latest_version):  # pragma: no cover
         if latest_version is None:
             return
 
         if latest_version < '0.4.1':
             self.pre_migration_0_4_1_fields_become_polymorphic(latest_version)
 
-    def pre_migration_0_4_1_fields_become_polymorphic(self, latest_version):
+    def pre_migration_0_4_1_fields_become_polymorphic(
+        self, latest_version
+    ):  # pragma: no cover
         logger.info("Pre Migration %s => %s: Field, Column, Relation Ship "
                     "become prolymophic models" % (latest_version,
                                                    self.version))
