@@ -2,6 +2,7 @@
 #
 #    Copyright (C) 2014 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
 #    Copyright (C) 2019 Jean-Sebastien SUZANNE <js.suzanne@gmail.com>
+#    Copyright (C) 2021 Jean-Sebastien SUZANNE <js.suzanne@gmail.com>
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file,You can
@@ -18,6 +19,7 @@ from sqlalchemy.sql.expression import true
 from sqlalchemy import or_, and_, inspect
 from sqlalchemy_utils.models import NO_VALUE, NOT_LOADED_REPR
 from sqlalchemy.orm.session import object_state
+from sqlalchemy import delete, select, update as sqla_update
 
 
 class uniquedict(dict):
@@ -49,7 +51,7 @@ class SqlMixin:
                 value = state.attrs.get(
                     anyblok_column_prefix + key).loaded_value
             else:
-                continue
+                continue  # pragma: no cover
 
             if value == NO_VALUE:
                 value = NOT_LOADED_REPR
@@ -124,6 +126,48 @@ class SqlMixin:
         query.set_Model(cls)
         return query
 
+    @classmethod
+    def execute_sql_statement(cls, *args, **kwargs):
+        """call SqlA execute method on the session"""
+        return cls.anyblok.execute(*args, **kwargs)
+
+    @classmethod
+    def select_sql_statement(cls, *elements):
+        """ Facility to do a SqlAlchemy query::
+
+            stmt = MyModel.select()
+
+        is equal at::
+
+            from anyblok import select
+
+            stmt = select(MyModel)
+
+        but select can be overload by model and it is
+        possible to apply whereclause or anything matter
+
+        :param elements: pass at the SqlAlchemy query, if the element is a
+                         string then thet are see as field of the model
+        :rtype: SqlAlchemy Query
+        """
+        res = []
+        for f in elements:
+            if isinstance(f, str):
+                res.append(getattr(cls, f).label(f))
+            else:
+                res.append(f)
+
+        if res:
+            stmt = select(*res)
+        else:
+            stmt = select(cls)
+
+        return cls.default_filter_on_sql_statement(stmt)
+
+    @classmethod
+    def default_filter_on_sql_statement(cls, statement):
+        return statement
+
     is_sql = True
 
     @classmethod
@@ -147,13 +191,13 @@ class SqlMixin:
     def get_where_clause_from_primary_keys(cls, **pks):
         """ return the where clause to find object from pks
 
-        :param **pks: dict {primary_key: value, ...}
+        :param _*_*pks: dict {primary_key: value, ...}
         :rtype: where clause
         :exception: SqlBaseException
         """
         _pks = cls.get_primary_keys()
         for pk in _pks:
-            if pk not in pks:
+            if pk not in pks:  # pragma: no cover
                 raise SqlBaseException("No primary key %s filled for %r" % (
                     pk, cls.__registry_name__))
 
@@ -168,7 +212,7 @@ class SqlMixin:
             query = Model.query_from_primary_keys(**pks)
             obj = query.one()
 
-        :param **pks: dict {primary_key: value, ...}
+        :param _*_*pks: dict {primary_key: value, ...}
         :rtype: Query object
         """
         where_clause = cls.get_where_clause_from_primary_keys(**pks)
@@ -182,16 +226,13 @@ class SqlMixin:
         :rtype: instance of the model
         """
         query = cls.query_from_primary_keys(**pks)
-        if query.count():
-            return query.first()
-
-        return None
+        return query.one_or_none()
 
     @classmethod
     def from_multi_primary_keys(cls, *pks):
         """ return the instances of the model from the primary keys
 
-        :param *pks: list of dict [{primary_key: value, ...}]
+        :param _*pks: list of dict [{primary_key: value, ...}]
         :rtype: instances of the model
         """
         where_clause = []
@@ -204,10 +245,7 @@ class SqlMixin:
         where_clause = or_(*[and_(*x) for x in where_clause])
 
         query = cls.query().filter(where_clause)
-        if query.count():
-            return query.all()
-
-        return []
+        return query.all()
 
     def to_primary_keys(self):
         """ return the primary keys and values for this instance
@@ -224,10 +262,12 @@ class SqlMixin:
         :type: list of the primary keys name
         """
         C = cls.anyblok.System.Column
-        query = C.query().distinct(C.name).options(load_only(C.name))
+        query = C.query()
+        query = query.options(load_only(C.name))
         query = query.filter(C.model.in_(cls.get_all_registry_names()))
         query = query.filter(C.primary_key == true())
-        return query.all().name
+        # DISTINCT does not works on MySQL/MsSQL
+        return list(set(query.all().name))
 
     @classmethod_cache()
     def _fields_description(cls):
@@ -258,9 +298,9 @@ class SqlMixin:
         hybrid_property_columns = cls.hybrid_property_columns
         if 'polymorphic_identity' in cls.__mapper_args__:
             pks = cls.get_primary_keys()
-            fd = cls.fields_description(*pks)
+            fd = cls.fields_description(pks)
             for pk in pks:
-                if fd[pk].get('model'):
+                if fd[pk].get('model'):  # pragma: no cover
                     Model = cls.anyblok.get(fd[pk]['model'])
                     hybrid_property_columns.extend(
                         Model.get_hybrid_property_columns())
@@ -369,7 +409,7 @@ class SqlMixin:
             field_value, field_property = getattr(self, field), None
             try:
                 field_property = getattr(getattr(cls, field), 'property', None)
-            except FieldException:
+            except FieldException:  # pragma: no cover
                 pass
 
             # Deal with this data
@@ -433,7 +473,9 @@ class SqlMixin:
                                    not isinstance(y, Many2Many))
                                for mapper in y.column_names
                                if mapper.attribute_name == field)
-                if isinstance(_field, Column) and _field.foreign_key:
+                if (
+                    isinstance(_field, Column) and _field.foreign_key
+                ):  # pragma: no cover
                     rmodel = cls.anyblok.loaded_namespaces_first_step[
                         _field.foreign_key.model_name]
                     for rc in [x for x, y in rmodel.items()
@@ -452,7 +494,7 @@ class SqlMixin:
                   not isinstance(_field, Many2Many) and
                   'backref' in _field.kwargs):
                 res.add_in_res(field, [_field.kwargs['backref'][0]])
-            elif isinstance(_field, FakeRelationShip):
+            elif isinstance(_field, FakeRelationShip):  # pragma: no cover
                 res.add_in_res(field, [_field.mapper.attribute_name])
 
         return res
@@ -462,7 +504,7 @@ class SqlMixin:
         """ Find column and relation ship link with the column or relationship
         passed in fields.
 
-        :param *fields: lists of the attribute name
+        :param _*fields: lists of the attribute name
         :rtype: list of the attribute name of the attribute and relation ship
         """
         res = []
@@ -472,7 +514,7 @@ class SqlMixin:
         while _fields:
             field = _fields.pop()
             if not isinstance(field, str):
-                field = field.name
+                field = field.name  # pragma: no cover
 
             if field in res:
                 continue
@@ -500,7 +542,7 @@ def get_model_information(anyblok, registry_name):
         if depend != registry_name:
             for x, y in get_model_information(anyblok, depend).items():
                 if x not in model:
-                    model[x] = y
+                    model[x] = y  # pragma: no cover
 
     return model
 
@@ -516,7 +558,7 @@ class SqlBase(SqlMixin):
         modified_fields = {}
         for attr in state.manager.attributes:
             if not hasattr(attr.impl, 'get_history'):
-                continue
+                continue  # pragma: no cover
 
             added, unmodified, deleted = attr.impl.get_history(
                 state, state.dict)
@@ -530,23 +572,6 @@ class SqlBase(SqlMixin):
 
         return modified_fields
 
-    def update(self, **values):
-        """ Hight livel method to update the session for the instance
-        ::
-
-            self.update(val1=.., val2= ...)
-
-        ..warning::
-
-            the columns and values is passed as named arguments to show
-            a difference with Query.update meth
-
-        """
-        for x, v in values.items():
-            setattr(self, x, v)
-
-        return 1 if values else 0
-
     def expire_relationship_mapped(self, mappers):
         """ Expire the objects linked with this object, in function of
         the mappers definition
@@ -589,6 +614,11 @@ class SqlBase(SqlMixin):
         """
         self.anyblok.flag_modified(self, fields)
 
+    @classmethod
+    def delete_sql_statement(cls):
+        """Return a statement to delete some element"""
+        return cls.default_filter_on_sql_statement(delete(cls))
+
     def delete(self, byquery=False, flush=True):
         """ Call the SqlAlchemy Query.delete method on the instance of the
         model::
@@ -604,8 +634,10 @@ class SqlBase(SqlMixin):
         """
         if byquery:
             cls = self.__class__
-            cls.query().filter(*cls.get_where_clause_from_primary_keys(
-                **self.to_primary_keys())).delete()
+            self.execute_sql_statement(
+                delete(cls).where(
+                    *cls.get_where_clause_from_primary_keys(
+                        **self.to_primary_keys())))
             self.expunge()
         else:
             model = self.anyblok.loaded_namespaces_first_step[
@@ -618,6 +650,37 @@ class SqlBase(SqlMixin):
         if flush:
             self.anyblok.flush()
 
+    @classmethod
+    def update_sql_statement(cls):
+        return cls.default_filter_on_sql_statement(sqla_update(cls))
+
+    def update(self, byquery=False, flush=False, **values):
+        """ Hight livel method to update the session for the instance
+        ::
+
+            self.update(val1=.., val2= ...)
+
+        ..warning::
+
+            the columns and values is passed as named arguments to show
+            a difference with Query.update meth
+
+        """
+        if byquery:
+            cls = self.__class__
+            return self.execute_sql_statement(
+                sqla_update(cls).where(
+                    *cls.get_where_clause_from_primary_keys(
+                        **self.to_primary_keys())).values(**values)).rowcount
+
+        for x, v in values.items():
+            setattr(self, x, v)
+
+        if flush:
+            self.anyblok.flush()  # pragma: no cover
+
+        return 1 if values else 0
+
     @classmethod
     def insert(cls, **kwargs):
         """ Insert in the table of the model::
@@ -648,7 +711,7 @@ class SqlBase(SqlMixin):
         """
         instances = cls.anyblok.InstrumentedList()
         for kwargs in args:
-            if not isinstance(kwargs, dict):
+            if not isinstance(kwargs, dict):  # pragma: no cover
                 raise SqlBaseException("multi_insert method wait list of dict")
 
             instance = cls(**kwargs)
