@@ -199,6 +199,15 @@ class MigrationReport:
 
     def init_remove_index(self, diff):
         _, index = diff
+
+        if sgdb_in(self.migration.conn.engine, ['MySQL', 'MariaDB']):
+            if index.table.schema in (
+                'mysql',
+                'performance_schema',
+                'percona',
+            ):
+                return True
+
         if self.ignore_migration_for(index.table.schema,
                                      index.table.name) is True:
             return True
@@ -368,6 +377,15 @@ class MigrationReport:
 
     def init_remove_table(self, diff):
         table = diff[1]
+
+        if sgdb_in(self.migration.conn.engine, ['MySQL', 'MariaDB']):
+            if table.schema in (
+                'mysql',
+                'performance_schema',
+                'percona',
+            ):
+                return True
+
         table_name = (
             '%s.%s' % (table.schema, table.name)
             if table.schema else table.name)
