@@ -584,12 +584,12 @@ class TestBlokOptional:
         registry.upgrade(uninstall=('test-blok1',))
         testblok1 = Blok.query().filter(Blok.name == 'test-blok1').first()
         testblok6 = Blok.query().filter(Blok.name == 'test-blok6').first()
-        assert testblok1.state, 'uninstalled'
-        assert testblok1.version, '1.0.0'
+        assert testblok1.state == 'uninstalled'
+        assert testblok1.version == '1.0.0'
         assert testblok1.installed_version is None
-        assert testblok6.state, 'installed'
-        assert testblok6.version, '2.0.0'
-        assert testblok6.installed_version, '2.0.0'
+        assert testblok6.state == 'installed'
+        assert testblok6.version == '2.0.0'
+        assert testblok6.installed_version == '2.0.0'
 
     def test_update(self, registry_testblok):
         registry = registry_testblok
@@ -799,10 +799,12 @@ class TestBlokModel:
         from sqlalchemy.exc import IntegrityError
         with pytest.raises(IntegrityError):
             with registry.begin_nested():
-                registry.Test2.query().delete()
+                registry.Test2.execute_sql_statement(
+                    registry.Test2.delete_sql_statement())
 
         registry.upgrade(uninstall=('test-blok8',))
-        registry.Test2.query().delete()
+        registry.Test2.execute_sql_statement(
+            registry.Test2.delete_sql_statement())
 
     def test_auto_migration_is_between_pre_and_post_migration_1(
         self, registry_testblok
